@@ -10,6 +10,7 @@
 /* include any extra headers needed here */
 
 void pybonoboui_register_classes(PyObject *d);
+void pybonoboui_add_constants(PyObject *module, const gchar *strip_prefix);
 extern PyMethodDef pybonoboui_functions[];
 
 DL_EXPORT(void)
@@ -36,7 +37,5 @@ initui(void)
     pybonoboui_register_classes(d);
 
     /* add anything else to the module dictionary (such as constants) */
-
-    if (PyErr_Occurred())
-        Py_FatalError("could not initialise module ui");
+    pybonoboui_add_constants(m, "BONOBO_");
 }
