@@ -902,10 +902,10 @@ pygvfs_mime_application_new(GnomeVFSMimeApplication *mimeapp)
     for (i = 0, l = mimeapp->supported_uri_schemes; l; ++i, l = l->next)
 	PyList_SET_ITEM(uri_schemes, i, PyString_FromString((const char *) l->data));
 
-    return Py_BuildValue("sssOONO", mimeapp->id, mimeapp->name,
+    return Py_BuildValue("sssOiNO", mimeapp->id, mimeapp->name,
 			 mimeapp->command,
 			 mimeapp->can_open_multiple_files? Py_True : Py_False, 
-			 mimeapp->expects_uris? Py_True : Py_False,
+			 mimeapp->expects_uris,
 			 uri_schemes,
 			 mimeapp->requires_terminal? Py_True : Py_False);
 }
